package com.nextgen.core.repository;

import java.io.File;
import java.io.FileInputStream;
import java.util.concurrent.TimeUnit;

import javax.jcr.Binary;
import javax.jcr.Node;
import javax.jcr.Session;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.modeshape.connector.filesystem.FileSystemSource;
import org.modeshape.jcr.JcrConfiguration;
import org.modeshape.jcr.JcrEngine;
import org.modeshape.jcr.JcrRepository;
import org.modeshape.jcr.api.SecurityContext;
import org.modeshape.jcr.api.SecurityContextCredentials;

public class ModeShapeLargeFileInsertTest {

	JcrRepository repository = null;
	JcrEngine engine = null;
	Session session = null;
	
	String workspaceName = "default";
	String repositoryId = "content";
	
	@Before
	public void init() throws Throwable {
		JcrConfiguration configuration = new JcrConfiguration();
		
		configuration.repositorySource("store")
			.usingClass(FileSystemSource.class)
			.setDescription("The repository for our content")
			.setProperty("workspaceRootPath", "/home/nextgen/content")
			.setProperty("updatesAllowed", true);
		
		configuration.repository(repositoryId)
			.setSource("store");
		
		try {
            // Start the ModeShape engine ...
            this.engine = configuration.build();
            this.engine.start();

            // Now get the JCR repository instance ...
            this.repository = this.engine.getRepository(repositoryId);
        } catch (Exception e) {
            this.repository = null;
            throw e;
        }
        

    	SecurityContext securityContext = new SecurityContext() {

			@Override
			public String getUserName() {
				return "username";
			}

			@Override
			public boolean hasRole(String arg0) {
				return true;
			}

			@Override
			public void logout() {
				// Do something
			}
        };
        SecurityContextCredentials credentials = new SecurityContextCredentials(securityContext);
        session = repository.login(credentials, workspaceName);
	}
	
	@After
	public void destroy() throws Throwable {
		if (this.repository != null) {
            try {
                this.engine.shutdown();
                this.engine.awaitTermination(4, TimeUnit.SECONDS);
            } finally {
                this.repository = null;
            }
        }	
	}
	
	
	@Test
	public void testInsert() throws Throwable {

		// Insert a folder "video" and add a "abc.mp4" video file

		Node root = session.getRootNode();
		
		// Create folder node
		Node videoNode = root.addNode("video", "nt:folder");
		Node fileNode = videoNode.addNode("abc.mp4", "nt:file");
		
		Node resNode = fileNode.addNode ("jcr:content", "nt:resource");
        resNode.setProperty("jcr:mimeType", "video/mp4");
    	File file = new File("/home/nextgen/abc.mp4");
        Binary binary = (session.getValueFactory().createBinary(new FileInputStream(file)));
        resNode.setProperty("jcr:data",binary);

        session.save();
		
		binary.dispose();
	}
}

